summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--README.md2
-rw-r--r--config/pe/base.conf4
-rw-r--r--config/pe/brmsgw.conf6
-rw-r--r--config/pe/console.conf36
-rw-r--r--policy-pe/docker-install.sh16
-rw-r--r--pom.xml20
6 files changed, 42 insertions, 42 deletions
diff --git a/README.md b/README.md
index f0b39375..3d21d178 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-This source repository contains the files for building the OpenECOMP Policy Engine Docker images.
+This source repository contains the files for building the ONAP Policy Engine Docker images.
To build it using Maven 3, first build 'policy-common-modules', 'policy-engine', 'policy-drools-pdp', and 'policy-drools-applications' repositories, and then run: mvn prepare-package. This will pull the installation zip files needed for building the policy-pe and policy-drools Docker images into the target directory. It will not actually build the docker images; the following additional steps are needed to accomplish this:
diff --git a/config/pe/base.conf b/config/pe/base.conf
index f6f32033..f1c25e15 100644
--- a/config/pe/base.conf
+++ b/config/pe/base.conf
@@ -3,7 +3,7 @@ POLICY_HOME=/opt/app/policy
KEYSTORE_PASSWD=PolicyR0ck$
JDBC_DRIVER=org.mariadb.jdbc.Driver
-JDBC_URL=jdbc:mariadb://mariadb:3306/ecomp_sdk?failOverReadOnly=false&autoReconnect=true
+JDBC_URL=jdbc:mariadb://mariadb:3306/onap_sdk?failOverReadOnly=false&autoReconnect=true
JDBC_LOG_URL=jdbc:mariadb://mariadb:3306/log?failOverReadOnly=false&autoReconnect=true
JDBC_USER=policy_user
JDBC_PASSWORD=policy_user
@@ -20,5 +20,5 @@ jmx_fqdn=
ENVIRONMENT=TEST
#Micro Service Model Properties
-policy_msEcompName=
+policy_msOnapName=
policy_msPolicyName= \ No newline at end of file
diff --git a/config/pe/brmsgw.conf b/config/pe/brmsgw.conf
index bfb12a1d..8b884dae 100644
--- a/config/pe/brmsgw.conf
+++ b/config/pe/brmsgw.conf
@@ -26,11 +26,11 @@ UEB_TOPIC=PDPD-CONFIGURATION
UEB_API_KEY=
UEB_API_SECRET=
-groupID=org.openecomp.policy-engine
+groupID=org.onap.policy-engine
artifactID=drlPDPGroup
-VFW_GROUP_ID=org.openecomp.policy-engine.drools.vFW
+VFW_GROUP_ID=org.onap.policy-engine.drools.vFW
VFW_ARTIFACT_ID=policy-vFW-rules
-VDNS_GROUP_ID=org.openecomp.policy-engine.drools.vDNS
+VDNS_GROUP_ID=org.onap.policy-engine.drools.vDNS
VDNS_ARTIFACT_ID=policy-vDNS-rules
diff --git a/config/pe/console.conf b/config/pe/console.conf
index 85233072..22259f77 100644
--- a/config/pe/console.conf
+++ b/config/pe/console.conf
@@ -112,21 +112,21 @@ FW_PROXY=
FW_PORT=
#SMTP Server Details for Java Mail
-ecomp_smtp_host=
-ecomp_smtp_port=25
-ecomp_smtp_userName=
-ecomp_smtp_password=
-ecomp_smtp_emailExtension=
-ecomp_application_name=
-
-#-----------------------ECOMP-PORTAL-Properties----------------------
-
-ECOMP_REDIRECT_URL=http://portal.api.simpledemo.openecomp.org:8989/ECOMPPORTAL/login.htm
-ECOMP_REST_URL=
-ECOMP_UEB_URL_LIST=
-ECOMP_PORTAL_INBOX_NAME=
-ECOMP_UEB_APP_KEY=
-ECOMP_UEB_APP_SECRET=
-ECOMP_UEB_APP_MAILBOX_NAME=
-APP_DISPLAY_NAME=OpenECOMP Policy
-ECOMP_SHARED_CONTEXT_REST_URL=http://portal.api.simpledemo.openecomp.org:8989/ECOMPPORTAL/context
+onap_smtp_host=
+onap_smtp_port=25
+onap_smtp_userName=
+onap_smtp_password=
+onap_smtp_emailExtension=
+onap_application_name=
+
+#-----------------------ONAP-PORTAL-Properties----------------------
+
+ONAP_REDIRECT_URL=http://portal.api.simpledemo.openecomp.org:8989/ECOMPPORTAL/login.htm
+ONAP_REST_URL=
+ONAP_UEB_URL_LIST=
+ONAP_PORTAL_INBOX_NAME=
+ONAP_UEB_APP_KEY=
+ONAP_UEB_APP_SECRET=
+ONAP_UEB_APP_MAILBOX_NAME=
+APP_DISPLAY_NAME=ONAP Policy
+ONAP_SHARED_CONTEXT_REST_URL=http://portal.api.simpledemo.openecomp.org:8989/ECOMPPORTAL/context
diff --git a/pom.xml b/pom.xml
index 8115930e..e37a4cb0 100644
--- a/pom.xml
+++ b/pom.xml
@@ -1,6 +1,6 @@
<!--
============LICENSE_START=======================================================
- ECOMP Policy Engine - Docker files
+ ONAP Policy Engine - Docker files
================================================================================
Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
================================================================================
@@ -24,12 +24,12 @@
<modelVersion>4.0.0</modelVersion>
- <groupId>org.openecomp.policy.docker</groupId>
+ <groupId>org.onap.policy.docker</groupId>
<artifactId>docker</artifactId>
<version>1.1.0-SNAPSHOT</version>
<packaging>pom</packaging>
<name>Policy Engine - Docker build</name>
- <description>OpenECOMP Policy Docker Build</description>
+ <description>ONAP Policy Docker Build</description>
<properties>
<nexusproxy>https://nexus.onap.org</nexusproxy>
@@ -41,17 +41,17 @@
<repositories>
<repository>
<id>ecomp-releases</id>
- <name>OpenECOMP Release Repository</name>
+ <name>ONAP Release Repository</name>
<url>${nexusproxy}/${releases.path}</url>
</repository>
<repository>
<id>ecomp-staging</id>
- <name>OpenECOMP Staging Repository</name>
+ <name>ONAP Staging Repository</name>
<url>${nexusproxy}/${staging.path}</url>
</repository>
<repository>
<id>ecomp-snapshot</id>
- <name>OpenECOMP Snapshot Repository</name>
+ <name>ONAP Snapshot Repository</name>
<url>${nexusproxy}/${snapshots.path}</url>
</repository>
</repositories>
@@ -59,12 +59,12 @@
<distributionManagement>
<repository>
<id>ecomp-releases</id>
- <name>OpenECOMP Release Repository</name>
+ <name>ONAP Release Repository</name>
<url>${nexusproxy}/${releases.path}</url>
</repository>
<snapshotRepository>
<id>ecomp-snapshots</id>
- <name>OpenECOMP Snapshot Repository</name>
+ <name>ONAP Snapshot Repository</name>
<url>${nexusproxy}/${snapshots.path}</url>
</snapshotRepository>
</distributionManagement>
@@ -87,7 +87,7 @@
<overWriteSnapshots>true</overWriteSnapshots>
<artifactItems>
<artifactItem>
- <groupId>org.openecomp.policy.engine</groupId>
+ <groupId>org.onap.policy.engine</groupId>
<artifactId>install</artifactId>
<version>${project.version}</version>
<type>zip</type>
@@ -108,7 +108,7 @@
<overWriteSnapshots>true</overWriteSnapshots>
<artifactItems>
<artifactItem>
- <groupId>org.openecomp.policy.drools-pdp</groupId>
+ <groupId>org.onap.policy.drools-pdp</groupId>
<artifactId>install-drools</artifactId>
<version>${project.version}</version>
<type>zip</type>
diff --git a/policy-pe/docker-install.sh b/policy-pe/docker-install.sh
index fa9472f1..edce4221 100644
--- a/policy-pe/docker-install.sh
+++ b/policy-pe/docker-install.sh
@@ -120,7 +120,7 @@ function tomcat_component() {
"${POLICY_HOME}/servers/${COMPONENT_TYPE}/webapps/host-manager"
if [[ ${COMPONENT_TYPE} == console ]]; then
- install_ecomp_portal_settings
+ install_onap_portal_settings
fi
return 0
@@ -188,17 +188,17 @@ function configure_component() {
list_unexpanded_files ${POLICY_HOME}
}
-function install_ecomp_portal_settings() {
- echo "Install ecomp portal settings"
+function install_onap_portal_settings() {
+ echo "Install onap portal settings"
- # unpack ecomp war file
- mkdir -p "${POLICY_HOME}"/servers/console/webapps/ecomp
- cd "${POLICY_HOME}"/servers/console/webapps/ecomp
- unzip -q ../ecomp.war
+ # unpack onap war file
+ mkdir -p "${POLICY_HOME}"/servers/console/webapps/onap
+ cd "${POLICY_HOME}"/servers/console/webapps/onap
+ unzip -q ../onap.war
cd ${INSTALL_DIR}
# copy over the configured settings
- /bin/cp -fr "${POLICY_HOME}"/install/servers/ecomp/* "${POLICY_HOME}/servers/console/webapps/ecomp"
+ /bin/cp -fr "${POLICY_HOME}"/install/servers/onap/* "${POLICY_HOME}/servers/console/webapps/onap"
}
function check_r_file() {